@@ -68,7 +68,7 @@ class Py2NDevice:
                 name=info["deviceName"],
                 model=info["variant"],
                 serial=info["serialNumber"],
-                host=self.options.ip_address,
+                host=self.options.host,
                 mac=info["macAddr"],
                 firmware=f"{info['swVersion']}-{info['buildType']}",
                 hardware=info["hwVersion"],
