@@ -30,14 +30,14 @@ async def get_info(
     """Get info from device through REST call."""
     try:
         async with aiohttp_session.get(
-            f"http://{options.ip_address}{API_SYSTEM_INFO}",
+            f"http://{options.host}{API_SYSTEM_INFO}",
             raise_for_status=True,
             timeout=HTTP_CALL_TIMEOUT,
         ) as response:
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
-        _LOGGER.debug("host %s: error: %r", options.ip_address, error)
+        _LOGGER.debug("host %s: error: %r", options.host, error)
         raise error from err
 
     if not result["success"]:
@@ -52,7 +52,7 @@ async def get_status(
     """Get status from device through REST call."""
     try:
         async with aiohttp_session.get(
-            f"http://{options.ip_address}{API_SYSTEM_STATUS}",
+            f"http://{options.host}{API_SYSTEM_STATUS}",
             timeout=HTTP_CALL_TIMEOUT,
             auth=options.auth,
         ) as response:
@@ -62,7 +62,7 @@ async def get_status(
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
-        _LOGGER.debug("host %s: error: %r", options.ip_address, error)
+        _LOGGER.debug("host %s: error: %r", options.host, error)
         raise error from err
     except InvalidAuthError as err:
         _LOGGER.debug("host %s: error: %r", options, error)
@@ -80,7 +80,7 @@ async def restart(
     """Restart device through REST call."""
     try:
         async with aiohttp_session.get(
-            f"http://{options.ip_address}{API_SYSTEM_RESTART}",
+            f"http://{options.host}{API_SYSTEM_RESTART}",
             timeout=HTTP_CALL_TIMEOUT,
             auth=options.auth,
         ) as response:
@@ -90,7 +90,7 @@ async def restart(
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
-        _LOGGER.debug("host %s: error: %r", options.ip_address, error)
+        _LOGGER.debug("host %s: error: %r", options.host, error)
         raise error from err
     except InvalidAuthError as err:
         _LOGGER.debug("host %s: error: %r", options, error)
@@ -106,7 +106,7 @@ async def get_switches(
     """Get switches from device through REST call."""
     try:
         async with aiohttp_session.get(
-            f"http://{options.ip_address}{API_SWITCH_STATUS}",
+            f"http://{options.host}{API_SWITCH_STATUS}",
             timeout=HTTP_CALL_TIMEOUT,
             auth=options.auth,
         ) as response:
@@ -116,7 +116,7 @@ async def get_switches(
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
-        _LOGGER.debug("host %s: error: %r", options.ip_address, error)
+        _LOGGER.debug("host %s: error: %r", options.host, error)
         raise error from err
     except InvalidAuthError as err:
         _LOGGER.debug("host %s: error: %r", options, error)
@@ -134,7 +134,7 @@ async def test_audio(
     """Test device audio through REST call."""
     try:
         async with aiohttp_session.get(
-            f"http://{options.ip_address}{API_AUDIO_TEST}",
+            f"http://{options.host}{API_AUDIO_TEST}",
             timeout=HTTP_CALL_TIMEOUT,
             auth=options.auth,
         ) as response:
@@ -144,7 +144,7 @@ async def test_audio(
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
-        _LOGGER.debug("host %s: error: %r", options.ip_address, error)
+        _LOGGER.debug("host %s: error: %r", options.host, error)
         raise error from err
     except InvalidAuthError as err:
         _LOGGER.debug("host %s: error: %r", options, error)
@@ -163,7 +163,7 @@ async def set_switch(
     """Set switch value of device through REST call."""
     try:
         async with aiohttp_session.get(
-            f"http://{options.ip_address}{API_SWITCH_CONTROL}?switch={switch_id}&action={'on' if on else 'off'}",
+            f"http://{options.host}{API_SWITCH_CONTROL}?switch={switch_id}&action={'on' if on else 'off'}",
             timeout=HTTP_CALL_TIMEOUT,
             auth=options.auth,
         ) as response:
@@ -173,7 +173,7 @@ async def set_switch(
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
-        _LOGGER.debug("host %s: error: %r", options.ip_address, error)
+        _LOGGER.debug("host %s: error: %r", options.host, error)
         raise error from err
     except InvalidAuthError as err:
         _LOGGER.debug("host %s: error: %r", options, error)
